==> redirect_page_by_role-1.1.0.tar.gz: redirect_page_by_role/src/Controller/RedirectPageByRoleController.php <==
<?php

namespace Drupal\redirect_page_by_role\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Drupal\Core\Database\Database;
use Drupal\node\Entity\Node;
use Drupal\redirect_page_by_role\Service\EnableService;

/**
 * Class RedirectPageByRoleController.
 */
class RedirectPageByRoleController extends ControllerBase {

  /**
   * Redirect page By Role config.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  private $config;

  /**
   * Constructor.
   */
  public function __construct() {
    $this->config = $config = \Drupal::config('redirect_page_by_role.settings');
  }

  /**
   * Check if has any redirection rule for the node content type.
   *
   * @param Node $node
   *   Node content type.
   *
   * @return mixed
   *   Returns the type of the rule or FALSE.
   */
  public function contentTypeHasRule($node) {
    $node_content_type = $node->getType();
    $has_rules = $this->config->get('hasRules');

    /** @var EnableService $enabler */
    $enabler = \Drupal::service('redirect_page_by_role.enabler');
    $is_enabled = $enabler->isEnabled($node);

    if ($is_enabled) {
      return 'node';
    }

    if (in_array($node_content_type . '_general', $has_rules)) {
      return 'general';
    }

    return FALSE;
  }

  /**
   * Check and apply redirection rules for the node according to the user role.
   *
   * @param Node $node
   *   Node to check redirections rules.
   * @param array $user_roles
   *   Array with user's roles.
   * @param string $rule_type
   *   If node has only general content type rules or specific node rules.
   */
  public function checkRedirect(Node $node, array $user_roles, string $rule_type) {
    // Check if the user has the grant to bypass the redirect rules.
    if ($this->hasBypassRole($user_roles)) {
      return;
    }

    if ($rule_type == 'node') {
      $nid = $node->id();
      $redirect_rules = $this->getNodeRedirectRules($nid);

      foreach ($redirect_rules as $rule) {
        reset($rule);
        foreach ($user_roles as $role) {
          if ($rule->role != $role) {
            continue;
          }
          $redirect = new RedirectResponse($rule->redirect_to, $rule->status_code);
          $redirect->send();
        }
      }
    }

    $content_type = $node->getType();
    $redirect_rules = $this->getDefaultRedirectRules($content_type, $user_roles);

    foreach ($user_roles as $key => $role) {
      if (array_key_exists($role, $redirect_rules)) {
        $redirect = new RedirectResponse($redirect_rules[$role]['redirect_to'], $redirect_rules['status_code']);
        $redirect->send();
      }
    }


  }

  /**
   * @param string $content_type
   *   Node content type.
   * @param array $user_roles
   *   Array with user's roles.
   *
   * @return array
   *   Return array with the rules for the node content type
   *   according to user's roles.
   */
  private function getDefaultRedirectRules(string $content_type, array $user_roles) {
    $roles_rules = $this->config->get($content_type)['roles'];
    $default_redirect_rules = [];

    foreach ($roles_rules as $role => $rules) {
      if (empty($rules['redirect_to'])) {
        continue;
      }
      $default_redirect_rules[$role]['redirect_to'] = $rules['redirect_to'];
    }

    if (!empty($default_redirect_rules)) {
      $default_redirect_rules['status_code'] = $this->config->get('default_status_code');
    }

    return $default_redirect_rules;
  }

  /**
   * @param $nid
   *  Node id.
   *
   * @return mixed
   *  Return all specific redirection rules for the node.
   */
  public function getNodeRedirectRules($nid) {
    $select = Database::getConnection()->select('redirect_page_by_role_node', 'rn')
      ->fields('rn')
      ->condition('nid', $nid);

    return $select->execute()->fetchAll();

  }

  /**
   * @param array $user_roles
   *   Array with user's roles.
   *
   * @return bool
   *   True if user has grant to bypass the redirection rules.
   */
  private function hasBypassRole(array $user_roles) {
    $bypass_roles = $this->config->get('bypass_roles');
    foreach ($bypass_roles as $bypass_role) {
      foreach ($user_roles as $user_role) {
        if ($bypass_role == $user_role) {
          return TRUE;
        }
      }
    }
    return FALSE;
  }

}

==> redirect_page_by_role-1.1.2.tar.gz: redirect_page_by_role/src/Controller/RedirectPageByRoleController.php <==
<?php

namespace Drupal\redirect_page_by_role\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Drupal\Core\Database\Database;
use Drupal\node\Entity\Node;
use Drupal\redirect_page_by_role\Service\EnableService;

/**
 * Class RedirectPageByRoleController.
 */
class RedirectPageByRoleController extends ControllerBase {

  /**
   * Redirect page By Role config.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  private $config;

  /**
   * Constructor.
   */
  public function __construct() {
    $this->config = \Drupal::config('redirect_page_by_role.settings');
  }

  /**
   * Check if has any redirection rule for the node content type.
   *
   * @param Node $node
   *   Node content type.
   *
   * @return mixed
   *   Returns the type of the rule or FALSE.
   */
  public function contentTypeHasRule($node) {
    $node_content_type = $node->getType();
    $has_rules = $this->config->get('hasRules');

    /** @var EnableService $enabler */
    $enabler = \Drupal::service('redirect_page_by_role.enabler');
    $is_enabled = $enabler->isEnabled($node);

    if ($is_enabled) {
      return 'node';
    }

    if (in_array($node_content_type . '_general', $has_rules)) {
      return 'general';
    }

    return FALSE;
  }

  /**
   * Check and apply redirection rules for the node according to the user role.
   *
   * @param Node $node
   *   Node to check redirections rules.
   * @param array $user_roles
   *   Array with user's roles.
   * @param string $rule_type
   *   If node has only general content type rules or specific node rules.
   */
  public function checkRedirect(Node $node, array $user_roles, string $rule_type) {
    // Check if the user has the grant to bypass the redirect rules.
    if ($this->hasBypassRole($user_roles)) {
      return;
    }

    if ($rule_type == 'node') {
      $nid = $node->id();
      $redirect_rules = $this->getNodeRedirectRules($nid);

      foreach ($redirect_rules as $rule) {
        reset($rule);
        foreach ($user_roles as $role) {
          if ($rule->role != $role) {
            continue;
          }
          $redirect = new RedirectResponse($rule->redirect_to, $rule->status_code);
          $redirect->send();
        }
      }
    }

    $content_type = $node->getType();
    $redirect_rules = $this->getDefaultRedirectRules($content_type, $user_roles);

    foreach ($user_roles as $key => $role) {
      if (array_key_exists($role, $redirect_rules)) {
        $redirect = new RedirectResponse($redirect_rules[$role]['redirect_to'], $redirect_rules['status_code']);
        $redirect->send();
      }
    }


  }

  /**
   * @param string $content_type
   *   Node content type.
   * @param array $user_roles
   *   Array with user's roles.
   *
   * @return array
   *   Return array with the rules for the node content type
   *   according to user's roles.
   */
  private function getDefaultRedirectRules(string $content_type, array $user_roles) {
    $roles_rules = $this->config->get($content_type)['roles'];
    $default_redirect_rules = [];

    foreach ($roles_rules as $role => $rules) {
      if (empty($rules['redirect_to'])) {
        continue;
      }
      $default_redirect_rules[$role]['redirect_to'] = $rules['redirect_to'];
    }

    if (!empty($default_redirect_rules)) {
      $default_redirect_rules['status_code'] = $this->config->get('default_status_code');
    }

    return $default_redirect_rules;
  }

  /**
   * @param $nid
   *  Node id.
   *
   * @return mixed
   *  Return all specific redirection rules for the node.
   */
  public function getNodeRedirectRules($nid) {
    $select = Database::getConnection()->select('redirect_page_by_role_node', 'rn')
      ->fields('rn')
      ->condition('nid', $nid);

    return $select->execute()->fetchAll();

  }

  /**
   * @param array $user_roles
   *   Array with user's roles.
   *
   * @return bool
   *   True if user has grant to bypass the redirection rules.
   */
  private function hasBypassRole(array $user_roles) {
    $bypass_roles = $this->config->get('bypass_roles');
    foreach ($bypass_roles as $bypass_role) {
      foreach ($user_roles as $user_role) {
        if ($bypass_role == $user_role) {
          return TRUE;
        }
      }
    }
    return FALSE;
  }

}
